pyMonteCarlo
============

.. image:: https://img.shields.io/pypi/v/pymontecarlo.svg
.. image:: https://img.shields.io/travis/pymontecarlo/pymontecarlo.svg
.. image:: https://img.shields.io/codecov/c/github/pymontecarlo/pymontecarlo.svg

**pyMonteCarlo** is a programming interface to run identical simulations using 
different Monte Carlo programs. The interface was designed to have common input 
and output that are independent of any Monte Carlo code. This allows users to 
combine the advantages of different codes and to compare the effect of different 
physical models without manually creating and running new simulations for each 
Monte Carlo program. The analysis of the results is also simplified by the 
common output format where results are expressed in the same units.

**pyMonteCarlo** is currently under development.

Authors
-------

- `Philippe T. Pinard <https://github.com/ppinard>`_ (High Wycombe, United Kingdom)
- `Hendrix Demers <https://github.com/drix00>`_ (McGill University, Montreal, Canada)
- `Raynald Gauvin <http://www.memrg.com>`_ (McGill University, Montreal, Canada)
- `Silvia Richter <https://github.com/silrichter>`_ (`RWTH Aachen University <http://www.gfe.rwth-aachen.de/seiteninhalte_english/esma.htm>`_, Aachen, Germany)
